Girder |build-status| |docs-status|
===================================

*High-Performance Data Management Platform*

Documentation of the Girder platform can be found at
https://girder.readthedocs.org.

.. |build-status| image:: https://travis-ci.org/girder/girder.svg?branch=master
    :target: https://travis-ci.org/girder/girder
    :alt: Build Status

.. |docs-status| image:: https://readthedocs.org/projects/girder/badge?version=latest
    :target: https://girder.readthedocs.org
    :alt: Documentation Status
